@@ -1,16 +1,16 @@
 import dataclasses
-import functools
-import urllib.parse
-
 import logging
-from typing import Any, Optional, Dict, Union, Iterable
+import urllib.parse
+from typing import Any, Optional, Dict, Union
 
 from aiohttp import Payload
 from aiohttp.web_response import Response
-
+from dynamic_types.class_name import _prepare_class_name
+from dynamic_types.create import create_type, create_dataclass
 from init_helpers import custom_dumps
 from init_helpers.dict_to_dataclass import dict_to_dataclass, convert_to_type
 from yarl import URL
+
 from .charset import Charset
 from .http_status_codes import HttpStatusCode
 from .mime_types import ContentType
@@ -22,68 +22,10 @@ class Nothing:
     pass
 
 
-def _prepare_class_name(bases: list[type], modifier: Any) -> str:
-    def split_by_brackets(class_string: str) -> list[str]:
-        parts = class_string.split("[")
-        return parts
-
-    def remove_import_path(class_string: str) -> str:
-        res = class_string.rsplit(".", 1)[-1]
-        return res
-
-    name_base = "".join(
-        '_'.join(remove_import_path(part) for part in split_by_brackets(str(base)))
-        for base in bases + [modifier]
-    )
-    name_base = name_base.replace("typing.", "")
-    name_base = name_base.replace("class", "")
-    name_base = "".join(char if char.isalnum() else "_" for char in name_base)
-    result = ""
-    is_next_char_upper = True
-    for char in name_base:
-        if char.isalnum():
-            if is_next_char_upper:
-                is_next_char_upper = False
-                char = char.upper()
-            result += char
-        else:
-            is_next_char_upper = True
-
-    return result
-
-
-class HashableDict(dict):
-    def __hash__(self):
-        return hash(tuple(sorted(self.items())))
-
-
 class ErrorCode(int):
     pass
 
 
-@functools.cache
-def _create_type(name: str, bases: list[type], parameter_name_to_value: dict[str, Any]) -> type:
-    new_type = type(name, tuple(bases), parameter_name_to_value)
-    return new_type
-
-
-@functools.cache
-def _create_dataclass(name: str, bases: list[type], parameter_name_to_type: dict[str, type]) -> type:
-    new_type = type(name, tuple(bases), {name: None for name, type_ in parameter_name_to_type.items()})
-    new_type.__annotations__ = parameter_name_to_type
-    return new_type
-
-
-def create_type(name: str, bases: Iterable[type], parameter_name_to_value: dict[str, Any]) -> type:
-    return _create_type(name, tuple(bases), HashableDict(parameter_name_to_value))
-
-
-def create_dataclass(name: str, bases: Iterable[type], parameter_name_to_type: dict[str, type]) -> type:
-    new_type = _create_dataclass(name, tuple(bases), HashableDict(parameter_name_to_type))
-    dataclass_ = dataclasses.dataclass(new_type)
-    return dataclass_
-
-
 _FIXED_CONTENT_TYPE__NAME = "_fixed_content_type"
 _FIXED_STATUS_CODE__NAME = "_fixed_status_code"
 _FIXED_PAYLOAD_TYPE__NAME = "_fixed_payload_type"
@@ -290,10 +232,10 @@ class FileAnswer(Answer):
                  payload: Any,
                  file_name: str = None,
                  status: HttpStatusCode = HttpStatusCode.OK,
-                 headers: Optional[Dict[str, str]] = None,
-                 content_type: Optional[ContentType] = None,
+                 headers: dict[str, str] | None = None,
+                 content_type: ContentType | str | None = None,
                  charset: str = None
-                 ):
+                 ) -> None:
         if headers is None:
             headers = {}
 
